Package: shiny.fluent
Title: Microsoft Fluent UI for Shiny Apps
Version: 0.4.0
Authors@R: 
  c(
    person("Jakub", "Sobolewski", role = c("aut", "cre"), email = "opensource+jakub.sobolewski@appsilon.com"),
    person("Kamil", "Żyła", role = "aut", email = "kamil@appsilon.com"),
    person("Marek", "Rogala", role = "aut", email = "marek@appsilon.com"),
    person("Appsilon Sp. z o.o.", role = "cph", email = "opensource@appsilon.com")
  )
Description: 
  A rich set of UI components for building Shiny applications,
  including inputs, containers, overlays, menus, and various utilities.
  All components from Fluent UI (the underlying JavaScript library)
  are available and have usage examples in R.
URL: https://appsilon.github.io/shiny.fluent/,
        https://github.com/appsilon/shiny.fluent
License: LGPL-3
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.1
Depends: R (>= 2.10)
Imports: htmltools, jsonlite, purrr, shiny, shiny.react (>= 0.4.0)
Suggests: chromote, covr, dplyr, DT, ggplot2, glue, imola, knitr,
        leaflet, mockery, plotly, rcmdcheck, RColorBrewer, rmarkdown,
        sass, shiny.i18n (>= 0.3.0), shiny.router (>= 0.3.1), shinyjs,
        shinytest2, sortable, stringi, testthat (>= 3.0.0), tibble,
        withr
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2024-05-21 07:47:32 UTC; jakub
Author: Jakub Sobolewski [aut, cre],
  Kamil Żyła [aut],
  Marek Rogala [aut],
  Appsilon Sp. z o.o. [cph]
Maintainer: Jakub Sobolewski <opensource+jakub.sobolewski@appsilon.com>
Repository: CRAN
Date/Publication: 2024-05-21 10:40:02 UTC
Built: R 4.6.0; ; 2026-04-26 15:07:44 UTC; unix
