makePage <- function (title, subtitle, contents) {
  tagList(div(
    class = "page-title",
    span(title, class = "ms-fontSize-32 ms-fontWeight-semibold", style =
           "color: #323130"),
    span(subtitle, class = "ms-fontSize-14 ms-fontWeight-regular", style =
           "color: #605E5C; margin: 14px;")
  ),
  contents)
}

makeCard <- function(title, content) {
  div(
    class = "card ms-depth-8",
    Text(variant = "large", title, block = TRUE),
    div(
      style = "margin-top: 10px;",
      content
    )
  )
}
