footer <- Stack(
  tokens = list(childrenGap = 10),
  Text(variant="large", "Built with ❤ by Appsilon", block=TRUE),
  Text(variant="medium", nowrap = FALSE, "If you'd like to learn more, react out to us at hello@appsilon.com"),
  Text(variant="medium", nowrap = FALSE, "All rights reserved."),
)
